add_depths_to_ref: Add Read Depths To Ref

Description Usage Arguments Value Examples

View source: R/id_mutations.R

Description

Add column for total read depths for a given sample to reference df

Usage

1
add_depths_to_ref(ref, samp, samp.dir)

Arguments

ref

reference genome in "MixVir" format (genomic positions repeated for each associated feature they're associated with, etc.)

samp

Character vector length 1 storing the name of a csv file with data for one sample. Should have columns CHROM,POS,REF,ALT,DP,AF. Others will be ignored.

samp.dir

Directory storing sample file defined with parameter 'samp'.

Value

Data frame with cols "genomic_pos" "ref_base" "gene" "ref_codon" "ref_AA gene_aa_position" "ref_identity" "DP"

Examples

1

mikesovic/MixviR_v1 documentation built on Dec. 21, 2021, 6:56 p.m.