Description Usage Arguments Value Examples
Add column for total read depths for a given sample to reference df
1 | add_depths_to_ref(ref, samp, samp.dir)
|
ref |
reference genome in "MixVir" format (genomic positions repeated for each associated feature they're associated with, etc.) |
samp |
Character vector length 1 storing the name of a csv file with data for one sample. Should have columns CHROM,POS,REF,ALT,DP,AF. Others will be ignored. |
samp.dir |
Directory storing sample file defined with parameter 'samp'. |
Data frame with cols "genomic_pos" "ref_base" "gene" "ref_codon" "ref_AA gene_aa_position" "ref_identity" "DP"
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.